package enseirb.myinpulse.service.database.old_controllers_to_convert_to_services;

import enseirb.myinpulse.model.Appointment;
import enseirb.myinpulse.repository.AppointmentRepository;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.server.ResponseStatusException;

import java.time.LocalDate;
import java.time.LocalTime;
import java.util.Optional;

@RestController
public class AppointmentController {

    @Autowired AppointmentRepository appointmentRepository;

    @GetMapping("/Appointment")
    @ResponseBody
    public Iterable<Appointment> allAppointments() {
        return this.appointmentRepository.findAll();
    }

    @GetMapping("/Appointment/{id}")
    public Appointment getAppointmentById(@PathVariable Long id) {
        Optional<Appointment> appointment = this.appointmentRepository.findById(id);
        if (appointment.isEmpty()) {
            throw new ResponseStatusException(HttpStatus.NOT_FOUND, "Ce rendez vous n'existe pas");
        }
        return appointment.get();
    }

    @PostMapping("/Appointment")
    public Appointment addAppointment(@RequestBody Appointment appointment) {
        return this.appointmentRepository.save(appointment);
    }

    @PostMapping("/Appointment/{id}")
    public Appointment updateAppointment(
            @PathVariable Long id,
            LocalDate appointmentDate,
            LocalTime appointmentTime,
            LocalTime appointmentDuration,
            String appointmentPlace,
            String appointmentSubject) {
        Optional<Appointment> appointment = this.appointmentRepository.findById(id);
        if (appointment.isEmpty()) {
            throw new ResponseStatusException(HttpStatus.NOT_FOUND, "Ce rendez vous n'existe pas");
        }
        if (appointmentDate != null) {
            appointment.get().setAppointmentDate(appointmentDate);
        }
        if (appointmentTime != null) {
            appointment.get().setAppointmentTime(appointmentTime);
        }
        if (appointmentDuration != null) {
            appointment.get().setAppointmentDuration(appointmentDuration);
        }
        if (appointmentPlace != null) {
            appointment.get().setAppointmentPlace(appointmentPlace);
        }
        if (appointmentSubject != null) {
            appointment.get().setAppointmentSubject(appointmentSubject);
        }
        return this.appointmentRepository.save(appointment.get());
    }
}
